@@ -29,7 +29,7 @@ static void testTestCase_countTestCases(void)
 TestCallerRef TestCaseTest_caller(void)
 {
 	EMB_UNIT_TESTFIXTURES(fixtures) {
-		new_TestFixture("testRepeatedTest_countTestCases",testTestCase_run),
+		new_TestFixture("testTestCase_run",testTestCase_run),
 		new_TestFixture("testTestCase_countTestCases",testTestCase_countTestCases),
 	};
 
